@@ -258,14 +258,16 @@ def render_table(data, append_headers, append_lineno):
     n = math.ceil(len(data["rows"]) / length)
     html = []
     rows = []
-    for index in range(0, n+2):
+    for index in range(0, n):
         html.append(
+            ('<div class="item-{}">'
+            '<div class="container">'
             "<table  "
             'style="border-collapse: collapse" '
             'border="0" '
             'cellspacing="0" '
             'cellpadding="0">'
-            "<colgroup>"
+            "<colgroup>").format(index)
         )
         hidden_columns = set()
         for col in data["cols"]:
@@ -288,9 +290,8 @@ def render_table(data, append_headers, append_lineno):
             for row in data["rows"][index:length]:
                 rows.append(row)
         for i, row in enumerate(rows):
-            trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n+1,index*length,(index+1)*length)]
+            trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n,index*length,(index+1)*length)]
             append_lineno(trow, i)
-            # trow.append(('{}').format(row))
             for cell in row:
                 if cell["column"] in hidden_columns:
                     continue
@@ -321,6 +322,8 @@ def render_table(data, append_headers, append_lineno):
             trow.append("</tr>")
             html.append("\n".join(trow))
         html.append("</table>")
+        html.append("</div>")
+        html.append("</div>")
     return "\n".join(html)
 
 
@@ -335,9 +338,26 @@ def render_data_to_html(data, append_headers, append_lineno):
         <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bulma/0.7.4/css/bulma.min.css">
         <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma-carousel@4.0.3/dist/css/bulma-carousel.min.css">
         <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma-carousel@4.0.3/dist/css/bulma-carousel.min.css">
+        <style>
+            .hero {
+                height: 1080px !important;
+            }
+
+            .slider-navigation-previous {
+                display: none !important;
+            }
+
+            .slider-navigation-next {
+                display: none !important;
+            }
+        </style>
     </head>
     <body>
-        %s
+        <section class="hero has-carousel">
+            <div id="carousel-demo" class="hero-carousel">
+                %s
+            </div>
+        </section>
         <script src="https://cdn.jsdelivr.net/npm/bulma-carousel@4.0.3/dist/js/bulma-carousel.min.js"></script>
         <script>
             bulmaCarousel.attach('#carousel-demo', {
